class Workspace:
    path: str


class System:
    pass


class Goal:
    pass


class Intelligence:
    input_types: list[str]
    output_types: list[str]


class Auth:
    pass


class Monitor:
    pass


class Logger:
    pass



import typer

from helperize.log import get_logger

log = get_logger(__name__)

app = typer.Typer(
    no_args_is_help=True,
    help="Helper's gonna help.",
    context_settings={"help_option_names": ["-h", "--help"]},
    add_completion=False,
)


@app.command()
def ask(
    prompt: str = typer.Argument(..., help="Provide a text prompt to the model."),
) -> str | None | int:
    """🐧 Ask a question."""
    log.info(f"You asked: {prompt}")
    response = "Hello World!"
    log.info(f"Response: {response}")
    return response


if __name__ == "__main__":
    app()



import logging
from logging import Logger

from rich.console import Console
from rich.logging import RichHandler
from rich.markdown import Markdown

logging.basicConfig(
    # Configuration options: https://docs.python.org/3/library/logging.html#logrecord-attributes
    format="%(funcName)s() %(message)s",
    level=logging.INFO,
    # Rich markup in console logs! https://rich.readthedocs.io/en/stable/logging.html
    handlers=[RichHandler(rich_tracebacks=True)],
)


def get_logger(name: str | None) -> Logger:
    """Get a logger with our preferred settings.

    Usage:
        from helper.log import get_logger
        log = get_logger(__name__)
    """
    return logging.getLogger(name)


def markdown(spec: str) -> None:
    """Log rich markdown to the console.

    Usage:

        from helper.log import markdown

        markdown('''
    # Header

    - list item 1
    - list item 2

    ```Python
    def hello():
        print("Hello!")
    ```
        ''')
    """
    console = Console(log_time=False, log_path=False)
    console.log(Markdown(spec))
